from collections import OrderedDict

grammar = {
    "IvTep_MId_Charge": 20,
    "IvTep_MId_MHD": 8,
    "IvTep_MId_ResNr": 20,
    "IvTep_MId_WeNr": 20,
    "IvTep_MId_ThmKz": 1,
    "IvTep_PrimThmKz": 1,
    "IvTep_FifoDatum": 8,
    "IvTep_PosNr": 6,
    "IvArt_Bestand_Einheit": 5,
    "IvArt_HOSTUNITS_HostEinh": 5,
    "IvAusp_UrAusId_Mand": 3,
    "IvAusp_UrAusId_AusNr": 20,
    "IvAusp_UrAusId_HostAusKz": 5,
    "IvAusp_HostPosNr": 6,
    "IvArt_AId_Mand": 3,
    "IvArt_AId_ArtNr": 20,
    "IvArt_AId_Var": 5,
    "Mngs_Mng": 12,
    "Mngs_Gew": 12,
    "IvMatqk_HMATQ_HMatQ": 20,
    "IvTep_TeId": 18,
}

grammar_convert = OrderedDict(
    {
        "Telheader_Quelle": {
            "type": "str",
            "length": 10,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_source_q",
        },
        "Telheader_Ziel": {
            "type": "str",
            "length": 10,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_destination_q",
        },
        "Telheader_TelSeq": {
            "type": "int",
            "length": 6,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_sequence_number",
        },
        "Telheader_AnlZeit": {
            "type": "datetime",
            "length": 14,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_current_datetime",
        },
        "Satzart": {
            "type": "str",
            "length": 9,
            "dp": False,
            "dict_key": False,
            "df_val": "WATEPQ050",
            "df_func": False,
        },
        "IvTep_MId_Charge": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxAusp_MId_Charge",
            "df_val": False,
            "df_func": False,
        },
        "IvTep_MId_MHD": {
            "type": "date",
            "length": 8,
            "dp": False,
            "dict_key": False,
            "df_val": "20240413",
            "df_func": False,
        },
        "IvTep_MId_ResNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxAusp_MId_ResNr",
            "df_val": False,
            "df_func": False,
        },
        "IvTep_MId_WeNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": False,
        },
        "IvTep_MId_ThmKz": {
            "type": "bool",
            "length": 1,
            "dp": False,
            "dict_key": False,
            "df_val": "N",
            "df_func": False,
        },
        "IvTep_PrimThmKz": {
            "type": "bool",
            "length": 1,
            "dp": False,
            "dict_key": False,
            "df_val": "N",
            "df_func": False,
        },
        "IvTep_FifoDatum": {
            "type": "date",
            "length": 8,
            "dp": False,
            "dict_key": False,
            "df_val": "20240413",
            "df_func": False,
        },
        "IvTep_PosNr": {
            "type": "int",
            "length": 6,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": False,
        },
        "IvArt_Bestand_Einheit": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": "HostEinheit",
            "df_val": False,
            "df_func": False,
        },
        "IvArt_HOSTUNITS_HostEinh": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": False,
        },
        "IvAusp_UrAusId_Mand": {
            "type": "str",
            "length": 3,
            "dp": False,
            "dict_key": "RxAusp_AusId_Mand",
            "df_val": False,
            "df_func": False,
        },
        "IvAusp_UrAusId_AusNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxAusp_AusId_AusNr",
            "df_val": False,
            "df_func": False,
        },
        "IvAusp_UrAusId_HostAusKz": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": "RxAusp_AusId_HostAusKz",
            "df_val": False,
            "df_func": False,
        },
        "IvAusp_HostPosNr": {
            "type": "int",
            "length": 6,
            "dp": False,
            "dict_key": "RxAusp_HostPosNr",
            "df_val": False,
            "df_func": False,
        },
        "IvArt_AId_Mand": {
            "type": "str",
            "length": 3,
            "dp": False,
            "dict_key": "RxAusp_MId_AId_Mand",
            "df_val": False,
            "df_func": False,
        },
        "IvArt_AId_ArtNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxAusp_MId_AId_ArtNr",
            "df_val": False,
            "df_func": False,
        },
        "IvArt_AId_Var": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": "RxAusp_MId_AId_Var",
            "df_val": False,
            "df_func": False,
        },
        "Mngs_Mng": {
            "type": "float",
            "length": 12,
            "dp": 3,
            "dict_key": "BestMng",
            "df_val": False,
            "df_func": False,
        },
        "Mngs_Gew": {
            "type": "float",
            "length": 12,
            "dp": 3,
            "dict_key": False,
            "df_val": False,
            "df_func": False,
        },
        "IvMatqk_HMATQ_HMatQ": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "Matqgs_Matqg1",
            "df_val": False,
            "df_func": False,
        },
        "IvTep_TeId": {
            "type": "str",
            "length": 18,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_parent_id",
        },
    }
)
