from collections import OrderedDict

grammar = {
    "IvWevp_WevId_Mand": 3,
    "IvWevp_WevId_WevNr": 20,
    "IvWevp_WEAP_WeaId_Mand": 3,
    "IvWevp_WEAP_WeaId_WeaNr": 20,
    "IvWevp_WEAP_WeaId_HostWeaKz": 5,
    "IvWeap_ExtRef": 20,
    "IvWeap_HostPosNr": 6,
    "IvWevp_LiefSNr": 20,
    "IvWevp_MId_AId_Mand": 3,
    "IvWevp_MId_AId_ArtNr": 20,
    "IvWevp_MId_AId_Var": 5,
    "IvMatQk_HMATQ_HMatQ": 20,
    "IvWevp_LiefMngs_Mng": 12,
    "IvWevp_LiefMngs_Gew": 12,
    "IvArt_HOSTUNITS_HostEinh": 5,
    "IvArt_Bestand_Einheit": 5,
    "IvWevp_MId_Charge": 20,
    "IvWevp_MId_MHD": 8,
    "IvWevp_MId_ResNr": 20,
    "IvWevp_MId_WeNr": 20,
    "IvWevp_MId_ThmKz": 1,
}

grammar_convert = OrderedDict(
    {
        "Telheader_Quelle": {
            "type": "str",
            "length": 10,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_source_q",
        },
        "Telheader_Ziel": {
            "type": "str",
            "length": 10,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_destination_q",
        },
        "Telheader_TelSeq": {
            "type": "int",
            "length": 6,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_sequence_number",
        },
        "Telheader_AnlZeit": {
            "type": "datetime",
            "length": 14,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": "get_current_datetime",
        },
        "Satzart": {
            "type": "str",
            "length": 9,
            "dp": False,
            "dict_key": False,
            "df_val": "WEAPQ0050",
            "df_func": False,
        },
        "IvWevp_WevId_Mand": {
            "type": "str",
            "length": 3,
            "dp": False,
            "dict_key": "RxWeap_WeaId_Mand",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_WevId_WevNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxWeap_WeaId_WeaNr",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_WEAP_WeaId_Mand": {
            "type": "str",
            "length": 3,
            "dp": False,
            "dict_key": "RxWeap_WeaId_Mand",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_WEAP_WeaId_WeaNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxWeap_WeaId_WeaNr",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_WEAP_WeaId_HostWeaKz": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": "RxWeap_WeaId_HostWeaKz",
            "df_val": False,
            "df_func": False,
        },
        "IvWeap_ExtRef": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxWeap_ExtRef",
            "df_val": False,
            "df_func": False,
        },
        "IvWeap_HostPosNr": {
            "type": "int",
            "length": 6,
            "dp": False,
            "dict_key": "RxWeap_HostPosNr",
            "df_val": False,
            "df_func": False,
        },
        "RxWeap_AvLiefSNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxWeap_AvLiefSNr",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_AId_Mand": {
            "type": "str",
            "length": 3,
            "dp": False,
            "dict_key": "RxWeap_MId_AId_Mand",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_AId_ArtNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxWeap_MId_AId_ArtNr",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_AId_Var": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": "RxWeap_MId_AId_Var",
            "df_val": False,
            "df_func": False,
        },
        "IvMatQk_HMATQ_HMatQ": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "Matqgs_Matqg1",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_LiefMngs_Mng": {
            "type": "float",
            "length": 12,
            "dp": 3,
            "dict_key": "BestMng",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_LiefMngs_Gew": {
            "type": "float",
            "length": 12,
            "dp": 3,
            "dict_key": False,
            "df_val": False,
            "df_func": False,
        },
        "IvArt_HOSTUNITS_HostEinh": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": False,
        },
        "IvArt_Bestand_Einheit": {
            "type": "str",
            "length": 5,
            "dp": False,
            "dict_key": "HostEinheit",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_Charge": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxWeap_MId_Charge",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_MHD": {
            "type": "date",
            "length": 8,
            "dp": False,
            "dict_key": "RxWeap_MId_MHD",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_ResNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": "RxWeap_MId_ResNr",
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_WeNr": {
            "type": "str",
            "length": 20,
            "dp": False,
            "dict_key": False,
            "df_val": False,
            "df_func": False,
        },
        "IvWevp_MId_ThmKz": {
            "type": "bool",
            "length": 1,
            "dp": False,
            "dict_key": "RxWeap_MId_ThmKz",
            "df_val": False,
            "df_func": False,
        },
    }
)
